@@ -90,7 +90,7 @@ case "$1" in
     ;;
 esac
 
-/etc/init.d/apache2 force-reload
+invoke-rc.d apache2 force-reload
 
 
 exit 0
