@@ -290,15 +290,15 @@ class Application extends ApplicationConfig
 
         $AppConfig = new ApplicationConfig($this->configdir);
         $this->config = $AppConfig->load(basename($configfile));
-        $this->authz = $AppConfig->load($this->config['AUTHORIZATION']);
+        $this->authz = $AppConfig->load($this->getConfig('AUTHORIZATION','benno-authz.conf'));
 
         $this->module   = $MODULE;
         $this->_request = & $_REQUEST;
         $this->_session = & $_SESSION;
         $this->DEBUG = $this->getConfig('DEBUG');
 
-        $this->tpl_root = getcwd().'/'.$this->config['TEMPLATE_ROOT'].'/templates';
-
+        $this->tpl_root = getcwd().'/'.$this->getConfig('TEMPLATE_ROOT','../')
+                          .'/templates';
         $this->TPL = new Smarty;
         $this->TPL->compile_check = true;
 
@@ -458,7 +458,7 @@ class Application extends ApplicationConfig
     function tplConfig()
     {
         // initialize cache
-        $templates_cache_base = $this->getConfig('TEMPLATE_CACHE');
+        $templates_cache_base = $this->getConfig('TEMPLATE_CACHE','/var/cache/benno-web/templates_c');
         $templates_cache_skin = $templates_cache_base.'/'.$this->skin;
         if (!is_dir($templates_cache_skin)) {
             mkdir($templates_cache_skin);
@@ -538,12 +538,14 @@ class Application extends ApplicationConfig
     {
         $debug_vals   = preg_split('/,(\s+)?/',$this->DEBUG);
         $debug_global = array_shift($debug_vals);
+
         foreach ($debug_vals as $debug_entry) {
             list($debug_module,$level) = explode(':',$debug_entry);
             if ($debug_module == $module) {
                 return $level;
             }
         }
+        return $debug_global;
     }
 
 
@@ -879,6 +881,24 @@ class Application extends ApplicationConfig
         }
         $this->TPL->setTemplateDir($tpl_dir);
     }
+
+
+    /**
+     * response
+     *
+     * Print (raw) response without template and exit.
+     *
+     * @access public
+     * @param $response string
+     * @param $type string (default text/plain)
+     */
+    function response($response,$type='text/plain')
+    {
+        header("Content-Type: $type");
+        print $response;
+        $this->log('>>> eor ----------------------------------',1,'SPAF2');
+        exit();
+    }
 }
 
 ?>
