@@ -45,11 +45,11 @@ class Backend
     var $rest_pass;
     var $_curl;
 
-    function Backend ($base_url,$filter)
+    function Backend ($base_url,$rest_user,$rest_pass,$filter)
     {
         global $App;
-        $this->rest_user = 'benno2';
-        $this->rest_pass = $App->getConfig('SHARED_SECRET');
+        $this->rest_user = $rest_user;
+        $this->rest_pass = $rest_pass;
         $this->rest_ssl_verify = $App->getConfig('REST_SSL_VERIFY');
 
         $this->base_url = $base_url;
@@ -81,7 +81,7 @@ class Backend
         $header = $maildata['header'];
 
         $EMail = new EMail($sessionMailId,$archive,$bennoId,$header['From'],$header['To'],$header['Cc'],$header['Bcc'],$header['Subject'],$header['Date'],$header['Size'],$body);
-        $EMail->verified = $header['HashCheckPassed'];
+        $EMail->verified = $header['X-Benno-HashCheckPassed'];
 
         foreach ($maildata['attachments'] as $atm) {
             $Attachment = new Attachment($atm['name'],@$atm['content-type'], $atm['size']);
@@ -244,7 +244,8 @@ class Backend
     function _curl_query ($request_url,$query=false,$format='')
     {
         global $App;
-        $cookie_file = $App->getConfig('COOKIE_FILE').$App->getSession('USER')->id;
+        $cookie_file = $App->getConfig('COOKIE_FILE','/var/tmp/.benno.cookie')
+                      .$App->getSession('USER')->id;
 
         if (!$this->_curl) {
             $this->_curl = curl_init();
