@@ -47,6 +47,8 @@ class MailObject
     var $size;
     var $body;
     var $bodytype;
+    var $isError;
+    var $errorMsg;
 
 
     function MailObject($id,$permaId,$from='',$to='',$cc='',$bcc='',$subject='',$date='',$time='',$size='',$body='',$attachments=array())
@@ -64,6 +66,16 @@ class MailObject
         $this->body     = $body;
         $this->attachments = $attachments;
         $this->bodytype = 'text/plain';
+        $this->isError  = false;
+        $this->errorMsg = '';
+    }
+
+
+    function setError($msg_sym)
+    {
+        global $App;
+        $this->isError  = true;
+        $this->errorMsg = $App->getMsg($msg_sym);
     }
 
 }
