@@ -66,7 +66,7 @@ class Query
     function Query ($id,$archive='',$text='',$dateFrom='',$dateTo='',$sender='',$recipient='',$subject='',$headerName='',$headerValue='',$isAttachment=false,$isSpam=false,$type='Simple')
     {
         $this->id = $id;
-        $this->archvie = $archive;
+        $this->archive = $archive;
         $this->text = $text;          // content or search term
         $this->dateFrom = $dateFrom;
         $this->dateTo = $dateTo;
