@@ -98,18 +98,28 @@ class UserDA extends Persistence
     // load userdata from external userdb via script parameters
     function loadExternal ($script,$loadpass=false)
     {
+        global $App;
+
+        if (!is_executable($script)) {
+            $App->log('Authentication script "'.$script.'" is not executable.',2);
+            throw new Exception('ERR_EXECUTE');
+        }
 
         try {
             return $this->loadSExternal($script,$loadpass);
         }
         catch (Exception $e) {
-            // external auth via STDIN failed
-            error_log('External auth with STDIN protocol failed.');
-        }
-
-        if (!is_executable($script)) {
-            error_log('Authentication script '.$script.' is not executable.');
-            throw new Exception('ERR_INTERN');
+            $esc = $e->getMessage();
+            if ($esc == 'ERR_AUTH') {
+                throw new Exception('ERR_AUTH');
+            }
+            if ($esc != 'ERR_EXECUTE') {
+                // external auth via STDIN failed
+                $App->log('External auth with STDIN protocol failed.');
+            }
+            else { 
+                throw new Exception('ERR_EXECUTE');
+            }
         }
 
         if ($loadpass === false) {
@@ -132,8 +142,8 @@ class UserDA extends Persistence
         //  MAIL info@lw-systems.de
         $cmd = escapeshellcmd($script);
         $username = escapeshellcmd($this->id);
+        $App->log('(DEPRECATED) Call "'.$script.'" to authenticate.',0);
         $retvalue = shell_exec("$cmd \"$username\" \"$password\"");
-
         return $this->_check_external_return($retvalue);
     }
 
@@ -141,10 +151,7 @@ class UserDA extends Persistence
     // load userdata from external userdb via script stdin/out
     function loadSExternal ($script,$loadpass=false)
     {
-        if (!is_executable($script)) {
-            error_log('Authentication script '.$script.' is not executable.');
-            throw new Exception('ERR_INTERN');
-        }
+        global $App;
 
         if ($loadpass === false) {
             $password = $this->password;
@@ -162,6 +169,7 @@ class UserDA extends Persistence
 
         $cmd = escapeshellcmd($script);
         $process = proc_open($cmd, $fd, $pipes);
+        $App->log('Call "'.$script.'" to authenticate.',2);
 
         if (is_resource($process)) {
             // write "<username> <password>"
@@ -226,8 +234,14 @@ class UserDA extends Persistence
             }
         }
 
-        if (!$this->role)    { throw new Exception('ERR_AUTH');    }
-        if (!$this->archive) { throw new Exception('ERR_ARCHIVE'); }
+        if (!$this->role)    {
+            error_log("[User::external] ROLE not set by external auth");
+            throw new Exception('ERR_AUTH');
+        }
+        if (!$this->archive) {
+            error_log("[User::external] ARCHIVE not set by external auth");
+            throw new Exception('ERR_ARCHIVE');
+        }
         return FALSE;
     }
 
