@@ -86,6 +86,5 @@ $MailObject->time       = strftime($LOCALE['timeformat'],$mailDate);
 if ($errorMsg) {
     $MailObject->setError('ID_NOT_FOUND');
 }
-print json_encode($MailObject);
-eor();
+$App->response(json_encode($MailObject),'application/json');
 ?>
