@@ -31,10 +31,21 @@
  * Suite 330, Boston, MA  02111-1307  USA
  */
 
-$rest_user   = 'benno2';
-$rest_pass   = $App->getConfig('SHARED_SECRET');
-$base_url    = $App->getConfig('BASE_URL');
-$cookie_file = $App->getConfig('COOKIE_FILE').$User->id;
+$RESTconf = new ApplicationConfig($App->configdir);
+$RESTConf->load($App->getConfig('REST_CONFIG','rest.conf'));
+
+// defaults: compatibility to deprecated configuration
+$base_url  = $RESTconf->getConfig('BASE_URL','http://localhost:21080');
+$rest_user = $RESTconf->getConfig('REST_USER','benno2');
+$rest_pass = $RESTconf->getConfig('SHARED_SECRET',$App->getConfig('SHARED_SECRET'));
+
+$cookie_file = $App->getConfig('COOKIE_FILE','/var/tmp/.benno.cookie')
+              .$User->id;
+
+$archive = $App->getParam('archive');
+if ($archive == '') {
+    $archive = end($User->getArchives());
+}
 
 // bild path for REST request
 $req_self = $_SERVER['PHP_SELF'];      // /search/ or /mail/
@@ -52,8 +63,6 @@ $filterString = preg_replace('/\s/','%20',$filterString);
 
 $query_request = $_SERVER['QUERY_STRING'];
 $query_request = preg_replace('/[\&]?\bfilterQuery=[^\&]+/','',$query_request);
-$archives = $User->getArchives();
-$archive       = 'archive='.end($archives);
 $filterQuery   = 'filterQuery='.$filterString;
 $query_request = $filterQuery.'&'.$archive.'&'.$query_request;
 
@@ -69,10 +78,21 @@ curl_setopt($curl, CURLOPT_USERPWD, $rest_user.':'.$rest_pass);
 
 curl_setopt($curl, CURLOPT_RETURNTRANSFER,1);
 curl_setopt($curl, CURLOPT_TIMEOUT,30);
-curl_setopt($curl, CURLOPT_SSL_VERIFYHOST, 0);
 curl_setopt($curl, CURLOPT_COOKIEJAR, $cookie_file);
 curl_setopt($curl, CURLOPT_COOKIEFILE, $cookie_file);
 
+if (preg_match('/^https:/',$url)) {
+    $rest_ssl_verify = $App->getConfig('REST_SSL_VERIFY');
+    if ($rest_ssl_verify == 'YES') {
+        curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, true);
+        curl_setopt($curl, CURLOPT_SSL_VERIFYHOST, true);
+    }
+    else {
+        curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, false);
+        curl_setopt($curl, CURLOPT_SSL_VERIFYHOST, false);
+    }
+}
+
 // suppress using of 100-Continue requests
 curl_setopt($curl, CURLOPT_HTTPHEADER,array("Expect:"));
 
@@ -84,8 +104,7 @@ if($_SERVER['REQUEST_METHOD'] == 'POST'){
 	curl_setopt($curl, CURLOPT_POSTFIELDS, $post_data);
 }
 
-
-// prepare reqeust debugging
+// prepare request debugging
 $loglevel = $App->loglevelForModule('rest_backend');
 if ($loglevel >= 2) {
     curl_setopt($curl, CURLOPT_VERBOSE, true);
